pilas.video

Package pilas :: Package video |
[hide private]
[frames] | no frames]

# Source Code for Package pilas.video

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9
    10  '''
    11  import video
    12  import pilas
    13
    14  todos = []
    15
    16  from video import DeCamara
    17  from video import DePelicula
    18  '''
    19